On 11-Sep-20 8:06 PM, Stephen Hemminger wrote:
Replace master lcore with main lcore and slave lcore with worker lcore.
Mostly automatic replacement.

Signed-off-by: Stephen Hemminger <step...@networkplumber.org>
---
  app/test/autotest_test_funcs.py         |   2 +-
  app/test/meson.build                    |   2 +-
  app/test/test.c                         |   2 +-
  app/test/test_atomic.c                  |  26 +++---
  app/test/test_barrier.c                 |   2 +-
  app/test/test_compressdev_test_buffer.h |   2 +-
  app/test/test_cryptodev.c               |  12 +--
  app/test/test_distributor.c             |   8 +-
  app/test/test_distributor_perf.c        |  10 +--
  app/test/test_eal_flags.c               |  32 +++----
  app/test/test_efd.c                     |   2 +-
  app/test/test_efd_perf.c                |   2 +-
  app/test/test_func_reentrancy.c         |   6 +-
  app/test/test_hash_multiwriter.c        |   4 +-
  app/test/test_hash_readwrite.c          |  39 +++++----
  app/test/test_kni.c                     |  16 ++--
  app/test/test_lpm_perf.c                |   4 +-
  app/test/test_malloc.c                  |  12 +--
  app/test/test_mbuf.c                    |  33 ++++----
  app/test/test_mcslock.c                 |  28 +++----
  app/test/test_mempool_perf.c            |  10 +--
  app/test/test_mp_secondary.c            |   2 +-
  app/test/test_pdump.c                   |   2 +-
  app/test/test_per_lcore.c               |  14 ++--
  app/test/test_pmd_perf.c                |  20 ++---
  app/test/test_rcu_qsbr.c                |   2 +-
  app/test/test_rcu_qsbr_perf.c           |   2 +-
  app/test/test_ring_perf.c               |  14 ++--
  app/test/test_ring_stress_impl.h        |  10 +--
  app/test/test_rwlock.c                  |  28 +++----
  app/test/test_service_cores.c           |  14 ++--
  app/test/test_spinlock.c                |  34 ++++----
  app/test/test_stack.c                   |   2 +-
  app/test/test_stack_perf.c              |   6 +-
  app/test/test_ticketlock.c              |  36 ++++----
  app/test/test_timer.c                   | 106 ++++++++++++------------
  app/test/test_timer_racecond.c          |  26 +++---
  app/test/test_timer_secondary.c         |   2 +-
  app/test/test_trace_perf.c              |   4 +-
  39 files changed, 288 insertions(+), 290 deletions(-)


Overall,

Acked-by: Anatoly Burakov <anatoly.bura...@intel.com>

However, couple of missed instances below.

<snip>

--- a/app/test/test_func_reentrancy.c
+++ b/app/test/test_func_reentrancy.c
@@ -58,7 +58,7 @@ static rte_atomic32_t obj_count = RTE_ATOMIC32_INIT(0);
  static rte_atomic32_t synchro = RTE_ATOMIC32_INIT(0);
#define WAIT_SYNCHRO_FOR_SLAVES() do{ \
-       if (lcore_self != rte_get_master_lcore())                  \
+       if (lcore_self != rte_get_main_lcore())                  \
                while (rte_atomic32_read(&synchro) == 0);        \

Macro should've been renamed too, along with all of its usages.

diff --git a/app/test/test_cryptodev.c b/app/test/test_cryptodev.c
index 70bf6fe2c1a6..fc059fe3dcfc 100644
--- a/app/test/test_cryptodev.c
+++ b/app/test/test_cryptodev.c
@@ -479,29 +479,29 @@ testsuite_setup(void)
        char vdev_args[VDEV_ARGS_SIZE] = {""};
        char temp_str[VDEV_ARGS_SIZE] = {"mode=multi-core,"
                "ordering=enable,name=cryptodev_test_scheduler,corelist="};
-       uint16_t slave_core_count = 0;
+       uint16_t worker_core_count = 0;
        uint16_t socket_id = 0;
if (gbl_driver_id == rte_cryptodev_driver_id_get(
                        RTE_STR(CRYPTODEV_NAME_SCHEDULER_PMD))) {
/* Identify the Slave Cores
                 * Use 2 slave cores for the device args
                 */
@@ -479,29 +479,29 @@ testsuite_setup(void)
                        RTE_STR(CRYPTODEV_NAME_SCHEDULER_PMD))) {
/* Identify the Slave Cores
-                * Use 2 slave cores for the device args
+                * Use 2 worker cores for the device args
                 */


Missed the beginning of this comment.

<snip>

index f5ddd03d7670..ffa0fd2380a3 100644
--
Thanks,
Anatoly

Reply via email to